@@ -1,3 +1,6 @@
+"""Configuration management by extending :class:`yacs.config.CfgNode`.
+"""
+
 import os
 from typing import Dict, Any
 from pathlib import Path
@@ -11,6 +14,8 @@ BASE_KEY = "_BASE_"
 
 
 class CfgNode(_CfgNode):
+    """A subclass of yacs' CfgNode that additionally implements inheritance of configuration files and is compatible with recap URIs.
+    """
 
     def __init__(self, init_dict=None, key_list=None, new_allowed=False):
         def ensure_cfgnode(item):
@@ -26,17 +31,39 @@ class CfgNode(_CfgNode):
 
     @classmethod
     def load_yaml_with_base(cls, filename: os.PathLike) -> "CfgNode":
+        """Load a YAML configuration file that may inherit from other YAML files.
+
+        Args:
+            filename (os.PathLike): the path to the YAML file (can be a recap URI)
+
+        Returns:
+            CfgNode: the loaded configuration
+        """
+
         uri = URI(filename)
         with uri.open("r") as f:
             cfg = cls.load_cfg(f)
         if BASE_KEY in cfg:
-            base_cfg = cls.load_yaml_with_base(cfg[BASE_KEY])
+            base_uri = URI(cfg[BASE_KEY])
+            # If the URI of the base cfg is relative, it should be relative to the current YAML file
+            if not base_uri.is_absolute():
+                base_uri = uri.parent / base_uri
+            base_cfg = cls.load_yaml_with_base(base_uri)
             del cfg[BASE_KEY]
             base_cfg.merge_from_other_cfg(cfg)
             return base_cfg
         return cfg
 
     def merge_with_dict(self, overrides: Dict[str, Any]):
+        """Merge a dict of configurations into this configuration object.
+
+        The dict must contain string keys. 
+        The configuration hierarchy is accessed using the "." delimiter.
+
+        Args:
+            overrides (Dict[str, Any]): the dict of configurations to merge (overwrite)
+        """
+
         for key, value in overrides.items():
             child = self
             *path_segments, prop = key.split(".")
@@ -56,7 +83,14 @@ class CfgNode(_CfgNode):
                 return cfg_node
         return yaml.safe_dump(convert_node(self), **kwargs)
 
-    def params_dict(self):
+    def params_dict(self) -> Dict[str, Any]:
+        """Obtain a key-value map representing the configuration settings.
+
+        The keys use the "." delimiter to denote going down a level in the configuration hierarchy.
+
+        Returns:
+            Dict[str, Any]: the map
+        """
         params = dict()
         for k, v in self.items():
             if isinstance(v, CfgNode):
